import { ColorMatrix } from '@pixi/filter-color-matrix';
import { Graphics as Graphics_2 } from 'pixi.js';
import { Instant } from '@adsk/chronos-time';
import { Interval } from '@adsk/chronos-time';
import { Level } from '@adsk/chronos-time';
import * as PIXI from 'pixi.js';
import { TimeMarker } from '@adsk/chronos-timeslider';
import { TimePlayback } from '@adsk/chronos-timeslider';
import { TimeSelection } from '@adsk/chronos-timeslider';
import { TimeView } from '@adsk/chronos-timeslider';
import { Weekdays } from '@adsk/chronos-time';

/**
 * App class - Initialises and handles Pixi app and other timeslider UI components
 */
declare class App {
    private _app;
    private _detailView;
    private _playback;
    private _undoRedo;
    private _timeScrollbar;
    private _scaleControl;
    private readonly _timeScrollbarHeight;
    private readonly _timeSlider;
    private _cursorManipulator;
    private _tooltip;
    private _suroundOffset;
    private _lastTriggeredEvent;
    /**
     * Handles Pixi app and other timeslider UI components and connect actions to redux store
     * @param timeSlider - TimeSlider object
     */
    constructor(timeSlider: TimeSlider);
    /**
     * Returns cursor manipulator object
     */
    get cursorManipulator(): CursorManipulator;
    /**
     * Returns App ticker
     */
    ticker(): PIXI.Ticker;
    /**
     * Returns App view
     * @returns
     */
    view(): HTMLCanvasElement;
    /**
     * Returns App stage
     */
    stage(): PIXI.Container;
    /**
     * Returns App renderer
     */
    renderer(): PIXI.Renderer;
    /**
     * Returns Detail View
     */
    detailView(): DetailView;
    /**
     * Returns Tooltip handler object
     */
    get tooltip(): Tooltip;
    /**
     * Returns PlaybackControl handler object
     */
    get playbackControl(): PlaybackControl;
    /**
     * Returns ScaleControl handler onject
     */
    get scaleControl(): ScaleControl;
    /**
     * Initialises UI components
     */
    initUIComponents(): void;
    /**
     * Returns display track height.
     */
    displayTrackHeight(): number;
    /**
     * Sets undo redo controls visibility
     * @param v - Whether undo redo controls are visible
     */
    setUndoRedoControlsVisibility(v: boolean): void;
    /**
     * Initializes App
     */
    private _initialize;
    /**
     * Connect mouse events to App stage
     */
    private _connectMouseEventsToStage;
    /**
     * Resizes App on window resize
     * @param w - width
     * @param h - height
     */
    private _resize;
    /**
     * Updates the component placements
     */
    private _updateComponentPlacements;
    /**
     * Handle events
     */
    private _handleEvents;
}

/**
 * ChrnonosManager class for communication with Chronos Time and Chronos TimeSlider
 */
declare class ChronosManager {
    private _timeSliderController;
    private _selectionView;
    private _detailView;
    constructor(start: Instant, end: Instant);
    /**
     * @returns root timeview
     */
    get root(): TimeView;
    /**
     * @returns TimeView or undefined - visible domain
     */
    get detailView(): TimeView;
    /**
     * @returns Tick display level
     */
    getTickDisplayLevel(): Level;
    zoomDomain(start: Instant, end: Instant): void;
    /**
     * Moves root domain
     * @param start - time to move beginning of domain to
     */
    moveDomain(start: Instant): void;
    /**
     * @param val - Pixel value as a fraction of pixel domain.( 0 to 1)
     * eg. pixel value 30 in pixel domain of 0 to 1500 will be val = 30/1500 = 0.02
     * @param timeView - Timeview
     */
    getTimeAt(val: number, timeView?: TimeView): Instant;
    /**
     * @param timeLevel - time level
     * @param range - pixel range
     */
    getTickPositions(timeLevel: Level, range: [number, number]): number[];
    /**
     * Returns tick count
     * @param timeLevel - time level
     */
    getTickCount(timeLevel: Level): number;
    /**
     * @param instant - Instant for which pixel value to be found
     * @param range - pixel range
     * @param timeView - Timeview optional
     */
    getValueAt(instant: Instant, range: [number, number], timeView?: TimeView): number;
    /**
     * Returns previous time level
     * @param level - time level
     */
    getPreviousLevel(level: Level): Level;
    /**
     * Returns next time level
     * @param level - time level
     */
    getNextLevel(level: Level): Level;
    /**
     * Returns time selection counts
     */
    getSelectionCount(): number;
    /**
     * Returns TimeSelection for given timeselection names
     * @param tsName - name of time selection to find
     */
    getTimeSelection(tsName: string): TimeSelection | undefined;
    /**
     * @returns TimePlayback or undefined
     */
    getTimePlayback(): TimePlayback | undefined;
    /**
     * Returns timePlayback of given timeselection
     * @param parentTsName - Parent time selection name
     */
    getMarker(parentTsName: string): TimeMarker | undefined;
    /**
     * @returns all timeselections
     */
    getAllTimeSelections(): TimeSelection[];
    /**
     * @returns playstate of playback marker
     */
    getPlaybackState(): PlayState;
    /**
     * @returns playback's looping state
     */
    isPlaybackLooping(): boolean;
    getTicks(view: TimeView, level: Level): Instant[];
    private _syncDetailView;
    private _syncTimeSelectionList;
    /**
     * Adds playback at start of container
     */
    private _addPlayback;
    /**
     * Removes playback from time slider
     */
    private _removePlayback;
    /**
     * Handles animation control actions
     */
    private _handleACActions;
    /**
     * Sets playback speed
     * Removed handling action dtSCSpeedUp because of nested redux actions limitations and
     * according to name it should be handled in speed control, required changes are done here
     * @param newSpeed - playback speed
     */
    private _setPlaybackSpeed;
    /**
     * Syncs temporary view corresponding to time selection with time selection
     * @param selections - List of time selections
     */
    private _syncSelectionView;
    /**
     * Handles loop control actions
     * @param newState - playback state
     */
    private _setPlaybackLoop;
}

/**
 * Container class extending PIXI.Container
 */
declare class Container extends PIXI.Container {
    private _size;
    private readonly _timeSlider;
    /**
     * @param size - Size
     * @param timeSlider - TimeSlider object
     */
    constructor(size: ISize, timeSlider: TimeSlider);
    /**
     * Returns container width
     * @returns
     */
    get w(): number;
    /**
     * Returns container height
     * @returns
     */
    get h(): number;
    /**
     * Container size
     */
    get size(): ISize;
    set size(v: ISize);
    /**
     * Returns timeslider object
     * @returns
     */
    get timeSlider(): TimeSlider;
}

/**
 * CursorManipulator class - Mouse cursor manipulator
 */
declare class CursorManipulator {
    private readonly _renderer;
    private _isMouseDown;
    /**
     * @param renderer - Renderer object
     */
    constructor(renderer: PIXI.Renderer);
    /**
     * Set cursor icon on mouse events
     * @param cursor - cursor type (eg. grab,auto)
     * @param event - event type (eg. mousedown, mouseup, mouseupoutside or mouseover)
     * @returns
     */
    setCursor(cursor: string, event: string): void;
}

/**
 * DetailView class - initializes TimeSelectionContainer, TimeRuler and DisplayTrack
 */
declare class DetailView extends Graphics {
    /**
     * Returns timeRuler object
     */
    get timeRuler(): TimeRuler;
    private _displayTrack;
    private _timeRuler;
    private _tsContainer;
    private _pcIndicator;
    private _mouseDown;
    private _dateLabel;
    private _pciHideByOutside;
    private _lPEIndicator;
    private _rPEIndicator;
    private _mouseDownX;
    /**
     * @param timeSlider - TimeSlider object
     * @param size - Size
     */
    constructor(timeSlider: TimeSlider, size: ISize);
    /**
     * Sets precise time indicator state
     */
    showHidePreciseTimeIndicator(state: boolean): void;
    /**
     * Show pan extent indicator
     */
    private _showPanExtentIndicator;
    /**
     * Initializes pan extent indicators
     */
    private _initPanExtentIndicators;
    /**
     * Resizes DetailView control
     */
    private _clearAndRedraw;
    /**
     * Initializes detail view
     */
    private _init;
    /**
     * Initializes precise cursor indicator
     */
    private _initPreciseCursorIndicator;
    /**
     * Create childs of detailview
     */
    private _draw;
    /**
     * On mouse move event receiver
     */
    private _onMouseMove;
    /**
     * On mouse over event receiver
     */
    private _onMouseOver;
    /**
     * On mouse out event receiver
     */
    private _onMouseOut;
    /**
     * On mouse down event receiver
     */
    private _onMouseDown;
    /**
     * On mouse out event receiver
     */
    private _onMouseUp;
    /**
     * On mouse up out side event receiver
     */
    private _onMouseUpOutside;
    /**
     * Binds Detailview to mouse events
     */
    private _attachMouseEvents;
    /**
     * Updates x and y trasnform of displaytrack and timeruler
     */
    private _updateComponentPlacements;
}

/**
 * Graphics class extending PIXI.Graphics
 */
declare class Graphics extends PIXI.Graphics {
    isActive: boolean;
    isMouseDown: boolean;
    private _size;
    private readonly _timeSlider;
    /**
     * @param name - Graphics name
     * @param size - Graphics size
     * @param timeSlider - TimeSlider object
     */
    constructor(name: string, size: ISize, timeSlider: TimeSlider);
    /**
     * Graphics width
     */
    get w(): number;
    set w(v: number);
    /**
     * Graphics height
     */
    get h(): number;
    set h(v: number);
    /**
     * Graphics size
     */
    get size(): ISize;
    set size(v: ISize);
    /**
     * Returns timeslider
     */
    get timeSlider(): TimeSlider;
    /**
     * Returns graphics location
     */
    get location(): ILocation;
    /**
     * Action to perform on mouse hover
     */
    onMouseOver(): void;
    /**
     * Action to perform on mouse out
     */
    onMouseOut(): void;
    /**
     * Attaches mouse wheel events depending on browser type
     */
    attachMouseWheelEvents(): void;
    refresh(): void;
    /**
     * Action to perform on mouse wheel movement
     * @param event - mouse wheel event
     */
    private _onMouseWheel;
}

declare namespace Highlighters {
    export {
        Highlighter,
        DayOfWeekHighlighter,
        HistogramHighlighter,
        Weekdays
    }
}
export { Highlighters }

/**
 * Interface Icolor with properties hex and alpha (number type)
 */
declare interface IColor {
    readonly hex: number;
    readonly alpha: number;
}

declare interface IEventData {
    start?: string;
    end?: string;
    time?: string;
    currentTime?: string;
}

/**
 * Interface ILocation with properties x and y (number type)
 */
declare interface ILocation {
    x: number;
    y: number;
}

/**
 * Interface ISize with properties w and h (number type)
 */
declare interface ISize {
    w: number;
    h: number;
}

/**
 * PlaybackControl class - initialises playback controls
 */
declare class PlaybackControl extends Container {
    private _play;
    private _pause;
    private _stop;
    private _loop;
    private _speed;
    private readonly _buttonSize;
    private readonly _offset;
    /**
     * @param timeSlider - TimeSlider object
     */
    constructor(timeSlider: TimeSlider);
    /**
     * Enable or disable the controls
     * @param timeSelections - timeselection
     */
    private _enableDisableControls;
    /**
     * Resizes playback control
     */
    private _clearAndRedraw;
    private _updateButtonLocations;
    /**
     * Creates play button
     */
    private _createControls;
    /**
     * On mouse click on play button
     */
    private _onPlayClick;
    /**
     * On mouse click on pause button
     */
    private _onPauseClick;
    /**
     * On mouse click on stop button
     */
    private _onStopClick;
    /**
     * Toggles control states
     * @param state - state to set
     */
    private _toggleControls;
}

/**
 * Interface PlayState with properties PLAY, PAUSE and STOP
 */
declare const enum PlayState {
    PLAY = 0,
    PAUSE = 1,
    STOP = 2
}

/**
 * PlaybackControl class - initialises playback control
 */
declare class ScaleControl extends Container {
    private _zoomIn;
    private _zoomOut;
    private _bg;
    private readonly _buttonSize;
    private _animateZoomIn;
    private _animateZoomOut;
    private _buttonStyle;
    /**
     * @param timeSlider - TimeSlider object
     */
    constructor(timeSlider: TimeSlider);
    /**
     * Enables or disables scale controls
     */
    private _enableDisableControl;
    /**
     * Resizes playback control
     */
    private _clearAndRedraw;
    /**
     * Does zoomIn operation
     * @param forceScale - zoom state
     */
    private _doZoomIn;
    /**
     * Does zoomOut operation
     * @param forceScale - force scale
     */
    private _doZoomOut;
}

/**
 * ThemeManager
 */
declare class ThemeManager {
    private _themeData;
    private readonly _fontFamily;
    private _resourceLoader;
    /**
     * @param theme - theme object
     */
    constructor(theme?: any);
    /**
     * Sets theme
     * @param themeId - Theme id
     * @param theme - theme
     * @returns
     */
    setTheme(themeId: string, theme: any): void;
    getThemeValue(s: string): any;
    getThemeValueOld(s: string): string;
    /**
     * APP Styles
     * Returns object with properties backgroundColor, roundedPlaybackControls, fontFamily, fontStyle,
     * fontWeight, buttonColor, buttonSize, disableAlpha, enableAlpha
     */
    APP: () => {
        backgroundColor: IColor;
        roundedPlaybackControls: boolean;
        fontFamily: string;
        fontStyle: string;
        fontWeight: string;
        buttonColor: IColor;
        buttonSize: number;
        disableAlpha: number;
        enableAlpha: number;
    };
    /**
     * TimeSelectionRangeHandle Styles
     * Returns object with properties backColor, hoverColor, activeColor, labelColor
     */
    TimeSelectionRangeHandle: () => {
        backColor: IColor;
        hoverColor: IColor;
        activeColor: IColor;
        labelColor: IColor;
    };
    /**
     * TimeSelection Styles
     * Returns object with properties backColor, backColorSelected, backColorHover, borderColor,
     * borderWidth
     */
    TimeSelection: () => {
        backColor: IColor;
        backColorSelected: IColor;
        backColorHover: IColor;
        borderColor: IColor;
        borderWidth: number;
    };
    /**
     * DayHighlighter Styles
     * Returns object with properties backColor, backColorHover, borderColor, borderWidth
     */
    DayHighlighter: () => {
        backColor: IColor;
        backColorHover: IColor;
        borderColor: IColor;
        borderWidth: number;
    };
    /**
     * Time Selection Indicator Styles
     * Returns object with properties backColor, lineColor
     */
    TimeSelectionIndicator: () => {
        backColor: IColor;
        lineColor: IColor;
    };
    /**
     * Playback Indicator Styles
     */
    PlaybackIndicator: () => {
        backColor: IColor;
    };
    /**
     * TimeMarker Styles
     * Returns object with properties backColor
     */
    TimeMarker: () => {
        backColor: IColor;
    };
    /**
     * TimeLabel Styles
     * Returns object with properties backColor, fontStroke, fontFamily
     */
    TimeLabel: () => {
        backColor: IColor;
        fontStroke: IColor;
        fontFamily: string;
    };
    /**
     * PlaybackMarker Styles
     * Returns object with properties backColor
     */
    PlaybackMarker: () => {
        backColor: IColor;
    };
    /**
     * DisplayTrack Styles
     * Returns object with properties backColor, borderColor, textColor
     */
    DisplayTrack: () => {
        backColor: IColor;
        borderColor: IColor;
        textColor: IColor;
    };
    /**
     * TimeRuler Styles
     * Returns object with properties baseColor, maskColor, fontStroke, fontFamily, ALLTickScheme,
     * MILLENIUM, CENTURY, DECADE, YEAR, MONTH, DATE, HOUR, MINUTE, SECOND, MILLISECOND
     */
    TimeRuler: () => {
        baseColor: IColor;
        maskColor: IColor;
        lineColor: IColor;
        fontStroke: number;
        fontFamily: string;
        ALLTickScheme: boolean;
        MILLENIUM: number[];
        CENTURY: number[];
        DECADE: number[];
        YEAR: number[];
        MONTH: number[];
        DATE: number[];
        HOUR: number[];
        MINUTE: number[];
        SECOND: number[];
        MILLISECOND: number[];
    };
    /**
     * Pan Extent Indicator Styles
     * Returns object with properties backColor
     */
    PanExtentIndicator: () => {
        backColor: IColor;
    };
    /**
     * TimeScrollbar Styles
     * Returns object with properties lineColor, backColor, hoverColor, activeColor, labelColor,
     * roundedShape
     */
    TimeScrollbar: () => {
        lineColor: IColor;
        baseColor: IColor;
        hoverColor: IColor;
        activeColor: IColor;
        labelColor: IColor;
        roundedShape: boolean;
    };
    /**
     * Scrollbar Styles
     * Returns object with properties lineColor, thumbColor
     */
    Scrollbar: () => {
        lineColor: IColor;
        thumbColor: IColor;
    };
    /**
     * Precise Cursor Indicator Styles
     * Returns object with properties lineColor
     */
    PreciseCursorIndicator: () => {
        lineColor: IColor;
    };
    /**
     * Tooltip Styles
     * Returns object with properties backColor, lineColor, fontStroke, fontFamily,
     * fontSize
     */
    Tooltip: () => {
        backColor: IColor;
        lineColor: IColor;
        fontStroke: IColor;
        fontFamily: string;
        fontSize: number;
    };
    /**
     * Loads resources to be used
     * @returns
     */
    loadResources(loadIconsFromSerevr: boolean): Promise<void>;
    /**
     * Gets icon
     * @param name - Name of Icon
     */
    getIcon(name: string): PIXI.Texture | undefined;
    /**
     * Converts color string to color matrix array
     * @param hex - hexadecimal color string
     * @returns float array
     */
    stringToColorMatrix(hex: string): ColorMatrix;
    /**
     * converts color string to hex value
     * @param name - Color string
     * @param defaultColor - Default Color
     */
    private _string2hex;
    /**
     * return hex value and alpha for given rgba values
     * @param rgba - rgba values
     */
    private _rgba2hex;
}

declare enum TimeFormat {
    DEFAULT_MS = "YYYY-MM-DDTHH:mm:ss.SSS",
    DEFAULT_S = "YYYY-MM-DDTHH:mm:ss",
    LT = "LT",
    LTS = "LTS",
    l = "l",
    L = "L",
    LL = "LL",
    ll = "ll",
    LLL = "LLL",
    lll = "lll",
    LLLL = "LLLL",
    llll = "llll"
}

/**
 * TimeRuler class - initialises time ruler
 */
declare class TimeRuler extends Graphics {
    private _base;
    private _highlighters;
    private _zoomFactor;
    private _dragOffset;
    private _tickContainer;
    private _minTickGap;
    private _maxTickGap;
    private _baseColor;
    private _lineColor;
    private _percentZoomedIn;
    private _isMouseOver;
    private _mjTl;
    private _mdTl;
    private _mnTl;
    private _mjH;
    private _mdH;
    private _mnH;
    private _mjTFs;
    private _mdTFs;
    private _mnTFs;
    private _animationOffset;
    private _animationSpeed;
    private _direction;
    private _labelArray;
    private _pxRange;
    private readonly _visFactor;
    private readonly _to;
    private readonly _localSize;
    private readonly _location;
    private readonly _showFctMap;
    private _preMousePos;
    private _prevVisualWidth;
    private _timer;
    private _initialTS;
    private _autoScrollTimer;
    private _kineticInterval;
    private _mouseDownPos;
    private _mouseUpPos;
    private _endTS;
    private _singleMoveDistance;
    /**
     * @param timeSlider - TimeSlider object
     * @param size - Size
     */
    constructor(timeSlider: TimeSlider, size: ISize);
    /**
     * Refresh the timeruler
     * @returns
     */
    refresh(): void;
    /**
     * Add highlighter
     *
     * @param highlighter - highlighter to add
     * @returns void
     */
    addHighlighter(highlighter: Highlighter): void;
    /**
     * Remove highlighter
     *
     * @param higlighter - highlighter to remove
     * @returns void
     */
    removeHighlighter(highlighter: Highlighter): void;
    /**
     * Zooms the timeruler
     * @param start - beginning of time range to zoom to
     * @param end - end of time range to zoom to
     */
    zoomTo(start: Instant, end: Instant): void;
    /**
     * Resizes Time ruler and its childs
     * @returns
     */
    private _clearAndRedraw;
    /**
     * Initialises time ruler
     * @returns
     */
    private _init;
    /**
     * Initializes timeRuler's style and colors
     * @returns
     */
    private _initStyleAndColors;
    /**
     * Draws Time ruler
     * @returns
     */
    private _draw;
    /**
     * Redraws the tick container
     */
    private _callredrawTickContainer;
    /**
     * Action to perform on mouse down
     * @param event - mouse down event
     */
    private _onMouseDown;
    /**
     * Action to perform on mouse move
     * @param event - mousemove event
     */
    private _onMouseMove;
    /**
     * Action to perform on mouse up
     * @param event - mouse up event
     */
    private _onMouseUp;
    /**
     * Automatic scroll ruler
     * @param speed - speed of scrolling
     */
    private _autoScroll;
    /**
     * Scrolls ruler
     * @param speed - speed of scrolling
     * @param dir - direction of scrolling
     */
    private _scroll;
    /**
     * Action to perform on mouse over
     */
    private _onMouseOver;
    /**
     * Action to perform on mouse out
     */
    private _onMouseOut;
    /**
     * Attaches events on mouse actions
     */
    private _attachEvents;
    /**
     * Checks mouse state
     */
    private _checkMouseState;
    /**
     * Calculate distance for Indicators (eg. Timeselection and Playback) to set position to the center
     */
    private _calculateDistanceToTravel;
    /**
     * Check Timeselection position whether it is inside visual domain or not
     */
    private _checkTSPosition;
    /**
     * Correct time selection data using visual domain
     * @param tsName - Timeselection name
     * @param ts -Timeselection
     */
    private _correctTSData;
    /**
     *
     * Pan the ruler with direction
     * @param direction - Pan direction
     * @param tsName - Timeselection name
     */
    private _panRuler;
    /**
     * Checks if zoom is possible on current state
     */
    private _isZoomInPossible;
    private _destroyLabel;
    /**
     * Checks if all minor level labels are visible then return true
     * @param level - Time level of minor tick
     * @param tickType - Tick type
     * @param stepArr - Skipping array
     */
    private _drawSubTicks;
    /**
     * Depending upon level call drawTicks
     */
    private _retrieveTicks;
    /**
     * Redraws tick container
     */
    private _redrawTickContainer;
    /**
     * Draws left time label if fits
     */
    private _drawLeftTimeLableIfFits;
    /**
     * Updates tick count
     * @param tickCount - tick count
     */
    private _updateTickCount;
    /**
     * Draws new ticks
     */
    private _drawTicks;
    /**
     * Returns alpha value for ticks if fadein markings feature is ON
     * @param to - tick options
     */
    private _getFadeInAlpha;
    /**
     * Returns transition factor for height of ticks and labels
     */
    private _getTransitionFactorForHeight;
    /**
     * Returns transition factor for font size
     */
    private _getTransitionFactorForLabelSize;
    /**
     * creates new label
     * @param label - text
     * @param size - size
     * @param color - color
     */
    private _createNewLabel;
    /**
     * Updates root pixel domain in tims selection controller
     */
    private _updateRoot;
    /**
     * Returns step array according to given level
     * @param level - level of ticks
     */
    private _getSkippingSteps;
    /**
     * Returns step array according to given level for ticks
     * @param level - level of ticks
     */
    private _getSubTicksCount;
    /**
     * Returns sub tick array
     * @param minLevelTicks - Minor level ticks
     * @param range - pixel range
     */
    private _getSubTicksForMonth;
    /**
     * Returns tick array
     * @param timeLevel - level date instance
     * @param range - pixel range
     */
    private _getSubTicks;
    /**
     * Retuns number of ticks
     * @param level - level date instance
     */
    private _numberOfCorrespondanceTicks;
    /**
     * Retuns tick labels
     * @param level - level date instance
     * @param stepArr - Steps array
     * @param tickType - tick type
     */
    private _getTicksLabel;
    /**
     * @param stepArr - step Array to select a number from
     * @param showNumber - number to show
     */
    private _getValidShowNumber;
    /**
     * @param dateArrayLen - Date Array length
     * @param labelLen - Length of a label
     */
    private _getShowNumber;
    /**
     * Filters tick labels
     * @param d - date instant
     * @param level - chronos time level
     * @param skipNumber - skip value to check for
     */
    private _filterTickLabels;
    /**
     * Formats tick labels
     * @param d - date instant
     * @param level - chronos time level
     * @param tickType - type of tick
     */
    private _formatTickLabels;
    /**
     * Returns ordinal indicators to date values according to level
     * @param d - date instant
     * @param level - chronos time level
     */
    private _getOridinal;
    /**
     * get zooming factor based on ticklevel
     */
    private _getSmoothZoomConst;
    /**
     * moves time ruler by distance in pixel
     * @param distance - date instant
     * @param direction - direction
     */
    private _moveTRByDistance;
}

/**
 * TimeSlider class - Receives input and forward it to App class
 * @public
 */
export declare class TimeSlider {
    private readonly _chronosManger;
    private readonly _themeManager;
    private readonly _undoRedoManager;
    private _app;
    /**
     * @param w - Width
     * @param h - Height
     * @param dateStart - Start date
     * @param dateEnd - End date
     * @param theme - Theme
     */
    constructor(w: number, h: number, dateStart: string, dateEnd: string, theme?: any | undefined);
    /**
     * Plays playback marker (eg. play('2018-01-01T00:00:00.000Z'))
     * @param time - time from where to begin playback
     */
    play(time?: string): void;
    /**
     * Pauses current playback
     */
    pause(): void;
    /**
     * Stops current playback and resets playback
     */
    stop(): void;
    /**
     * Checks loop state of playback
     */
    isLooping(): boolean;
    /**
     * Checks whether playback is in play state
     */
    isPlaying(): boolean;
    /**
     * Checks whether playback is in pause state
     */
    isPaused(): boolean;
    /**
     * Checks whether playback is in stop state
     */
    isStopped(): boolean;
    /**
     * Creates a timeselection with specified time range
     * and returns name of created timeselection (eg. addTimeSelection('2000-01-01T00:00:00.000Z','2019-12-31T23:59:59.999Z'))
     * @param startTime - start time of selection
     * @param endTime - end time of selection
     */
    addTimeSelection(startTime: string, endTime: string, markerTime?: string): string;
    /**
     * Removes timeselection with specified name (eg. removeTimeSelection('ts_0'))
     * @param tsName - name of the time selection to be removed
     */
    removeTimeSelection(tsName: string): void;
    /**
     * Returns theme manager object
     */
    get themeManager(): ThemeManager;
    /**
     * Sets playback speed level
     * @param speedLevel - speedLevel value can be 1, 2, 4, 8, 16.
     */
    setPlaybackSpeed(speedLevel: number): void;
    /**
     * Sets playback time
     * @param time - playback time (duration).
     */
    setPlaybackTime(time?: number): void;
    /**
     * @returns Speed of playback
     */
    getPlaybackSpeed(): number;
    /**
     * Toggles loop state
     * Set Toggles loop state (eg. toggleLoop(true))
     */
    toggleLoop(state?: boolean): boolean;
    /**
     * Returns chronos manager
     */
    get chronosManager(): ChronosManager;
    /**
     * Returns App
     */
    get app(): App;
    /**
     * Returns Tooltip handler object
     */
    get tooltip(): Tooltip;
    /**
     * Returns playbackcontrol object
     */
    get playbackControl(): PlaybackControl;
    /**
     * Return HTMLCanvasElement
     */
    view(): HTMLCanvasElement;
    /**
     * Resizes app on window resize
     * @param w - width
     * @param h - height
     */
    resize(w: number, h: number): void;
    /**
     * Toggles the feature (eg. toggleFeature('use_undoredo',true))
     * @param featureName - name of the feature (eg. use_undoredo)
     * @param state - state of feature
     */
    toggleFeature(featureName: string, state: boolean): void;
    /**
     * Returns state of the given feature (eg. isFeatureEnabled('use_undoredo'))
     * @param featureName - name of the feature (eg. use_undoredo)
     */
    isFeatureEnabled(featureName: string): boolean;
    /**
     * Sets time indicator format to given format
     * @param format - time date format
     */
    setTimeIndicatorFormat(format: TimeFormat): void;


    /**
     * Returns time format
     */
    timeFormat(): string;
    /**
     * Sets state of user defined time format
     */
    useUserDefinedTimeIndicatorFormat(v: boolean): void;
    /**
     * Returns state of user defined time format
     */
    userDefinedTimeIndicatorFormat(): boolean;
    /**
     * Wrapper for changing theme
     * @param themeId - themeId
     * @param theme - theme
     */
    setTheme(themeId: string, theme: any): void;
    /**
     * Registers callback function in chronos manager
     * @param eventName - event name
     * @param cb - callback function
     */
    on(eventName: string, cb: (properties: IEventData) => void): void;
    /**
     * Removes callback function in chronos manager
     * @param eventName - event name
     * @param cb - callback function
     */
    off(eventName: string, cb?: (properties: IEventData) => void): void;
    /**
     * Zooms to new start and end time
     * @param startDateTime - start time
     * @param endDateTime - end time
     */
    zoomTo(startDateTime: string, endDateTime: string): void;
    /**
     * Undoes time selection changes
     */
    undo(): void;
    /**
     * Redoes time selection changes
     *
     * @public
     */
    redo(): void;
    /**
     * Whether an undo operation is available
     *
     * @public
     */
    canUndo(): boolean;
    /**
     * Whether a redo operation is available
     *
     * @public
     */
    canRedo(): boolean;
    /**
     * Refresh UI conponents
     */
    refresh(): void;
    /**
     * Sets whether to map playback rate with real time
     */
    mapPlaybackRateWithReal(v: boolean): void;
    set zoomToSelectionPadding(padding: number);
    /**
     * Padding between visible domain and selection boundaries in pixels
     */
    get zoomToSelectionPadding(): number;
    /**
     * Maximize time selection
     */
    zoomToSelection(padding?: number): void;
    /**
     * @param spriteArray - Array of sprites
     * @param displayObject - Display object to search
     */
    private _recursiveFindObjects;
}

/**
 * Tooltip class - initialises tooltip
 */
declare class Tooltip extends Graphics {
    private _backColor;
    private _lineColor;
    private _fontStroke;
    private _fontFamily;
    private _fontSize;
    private _tooltipText;
    private _fadeTimeOut;
    /**
     * @param timeSlider - TimeSlider object
     */
    constructor(timeSlider: TimeSlider);
    /**
     * Shows tooltip text
     * @param tooltip - tooltip text
     * @returns
     */
    show(tooltip: string): void;
    /**
     * Hides tooltip text
     * @returns
     */
    hide(): void;
    /**
     * Initializes DisplayTrack's style and colors
     * @returns
     */
    private _initStyleAndColors;
    /**
     * Resizes Displaytrack and its children
     * @returns
     */
    private _clearAndRedraw;
    /**
     * Sets position
     * @returns
     */
    private _transform;
    /**
     * Fade out tooltip
     * @returns
     */
    private _fadeOut;
}

export { }
